cmd

package
v0.1.1-beta Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: MIT Imports: 26 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() error

func GetAccountID

func GetAccountID() string

func GetFormat

func GetFormat() string

func GetPlain

func GetPlain() bool

GetPlain returns true if the --plain flag was set.

Types

This section is empty.

Directories

Path Synopsis
Package bxml provides local commands for generating Bandwidth XML (BXML).
Package bxml provides local commands for generating Bandwidth XML (BXML).

Jump to