version

package
v0.1.1-beta Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CheckResult

type CheckResult struct {
	Current string
	Latest  string
}

CheckResult is returned when a newer version is available.

func Check

func Check(currentVersion string) *CheckResult

Check compares the running version against the latest GitHub release. Returns nil if the version is current, the check was performed recently, or anything goes wrong (version checks should never block the user).

func (*CheckResult) NoticeMessage

func (r *CheckResult) NoticeMessage() string

NoticeMessage returns a user-friendly upgrade notice.

Jump to